==> fluxbox-1.0rc3.tar.bz2: fluxbox-1.0rc3/nls/es_AR/Translation.m <==
$ codeset=ISO-8859-15

$set 1 #Align

1 Abajo al centro
2 Abajo a la izquierda
3 Abajo a la derecha
4 Horizontal
5 Izquierda
6 A la izquierda abajo
7 A la izquierda al centro
8 A la izquierda arriba
9 Relativo
10 Derecha
11 A la derecha abajo
12 A la derecha al centro
13 A la derecha arriba
14 Arriba al centro
15 Arriba a la izquierda
16 Arriba a la derecha
17 Vertical

$set 2 #BaseDisplay

1 Abortando... volcando nucleo\n
2 Apagando\n
3 %s:       seal %d capturada\n

$set 3 #Common

1 Alfa 
2 Auto ocultar
3 Compilado
4 Opciones compiladas
5 Compilador
6 Versin del compilador
7      init
8      keys
9       nls
10      menu
11     style
12 Opciones por defecto
13 desactivado
14 Error
15 Versin de Fluxbox
16 Maximizar por encima
17 Revisin de SVN
18 Visible
19 No hay una opcin de fondo especificada en este estilo.\nPor vafor consulte el manual o lea las FAQ.


$set 4 #Configmenu

1 Anti alias
2 Elevar automticamente las ventanas
3 Seleccionar para elevar
4 Seleccionar para enfocar
5 Decorar las ventanas transitivas
6 Cambiar de escritorio con la rueda del mouse
7 Enfocar ltima ventana en el cambio de escritorio
8 Modelo de enfoque
9 Enfocar ventanas nuevas
10 Maximizacin total
11 Simulacin de colores en imgenes
12 Movimiento opaco de ventanas
13 Enfoque semi descuidado
14 El mouse enfoca
15 Workspace Warping
16 Forzar pseudo transparencias
17 Alfa del menu
18 Transparencia
19 Alfa de ventana enfocada
20 Alfa de ventana desenfocada
21 Opciones de solapas
22 solapas en barra de ttulo
23 Ancho de solapas externas
24 Click sobre la solapa enfoca
25 Mouse sobre la solapa enfoca

$set 5 #Ewmh

1 Fatal: Sin memoria, no se puede asignar la lista de clientes EWMH

$set 6 #FbTkError

1 Atencin! Altura > 3200, estableciendo Altura = 3200
2 Atencin! Ancho > 3200, estableciendo Ancho = 3200
3 Atencin: no se puede cargar la fuente
4 Error de asignacin
5 Error creando el pixmap
6 No se puede crear XImage
7 Error de lectura
8 Atencin: No se puede encontrar un formato vlido para el alfa
9 Atencin: Error al crear la imagen alfa
10 Atencin: Error al crear el pixmap alfa
11 No se puede encontrar un formato de pantalla(%d)
12 Sin memoria
13 Sin memoria mientras se asignaba buffer azul.
14 Sin memoria mientras se asignaba buffer verde.
15 Sin memoria mientras se asignaba buffer rojo.
16 Error de lectura en tem de tema
17 visual no soportada
18 Estableciendo el valor por defecto

$set 7 #Fluxbox

1 nombre de archivo rc invlido
2 Error al cargar archivo group
3 Error al cargar la base de datos
4 Reintentando con
5 Atencin! No se puede encontrar pantalla para mapear la ventana
6 No se puede crear el directorio %s
7 No se pudieron encontrar pantallas para manejar.\Asegrese que no tiene otro gestor de ventanas ejecutndose
8 Error interpretando expresin regular
9 Fatal! Slo puede haber una instancia de clase de FLuxbox
10 No se puede conectar con el servidor X.\Asegrese de iniciar las X antes de iniciar Fluxbox
11 Atencin: el servidor X no soporta sus locales
12 Atencin: no se pueden establecer modificadores de locales

$set 8 #Gnome

1 Fatal: Sin memoria, no se puede asignar la lista de clientes de GNOME

$set 9 #Keys

1 Keys: Error en la lnea
2 Keys: Error al emerger el rbol de teclas!
3 Keys: Tecla/modificador invlido la lnea

$set 10 #Menu

1 Configuracin
2 Men Fluxbox por defecto
3 Salir
4 Iconos
5 Capa...
6 A la cabeza...
7 Ubicacin
8 Recargar configuracin
9 Reiniciar
10 Atencin: etiquetas desbalanceadas [codificacin]

$set 11 #Remember

1 Decoraciones
2 Dimensiones
3 Saltar al escritorio
4 Capa
5 Recordar...
6 Posicin
7 Guardar al cerrar
8 Enrollado
9 Pegajoso
10 Tecla desconocida de aplicaciones
11 Escritorio
12 Cabeza

$set 12 #Screen

1 BScreen::BScreen: Ocurrinun error al consultar al servidor X.\n
2 W: %4d x H: %4d
3 BScreen::BScreen: manejando pantalla %d usando visual 0x%lx, profundidad %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Clientes
2 Ciclar hacia abajo
3 Ciclar hacia arriba
4 Direccin de slit
5 Capa de slit
6 Slit a la cabeza
7 Ubicacin de slit
8 Slit
9 Guardar lista de slit

$set 14 #Toolbar

1 Renombrar escritorio actual
2 Modo de la barra de iconos
3 Todas las ventanas
4 Iconos
5 Ninguno
6 Escritorio
7 Iconos del escritorio
8 Capa de la barra de herramientas
9 Toolbar a la cabeza
10 Ubicacin de la barra de herramientas
11 Barra de herramientas
12 Porcentaje de ancho de la barra de herramientas
13 Reloj: 24h
14 Reloj: 12h
15 Editar el formato de reloj
16 Mostrar imgenes
17 Sin iconos
18 No mostrar los iconos del escritorio

$set 15 #Window

1 Sin nombre

$set 16 #Windowmenu

1 Cerrar
2 Iconificar
3 Capa
4 Bajar
5 Maximizar
6 Elevar
7 Enviar a ...
8 Enrollar
9 Fijar
10 Matar

$set 17 #Workspace

1 Escritorio %d
2 Escritorios
3 Escritorio nuevo
4 Quitar el ltimo escritorio

$set 18 #fbsetroot

1 error: es necesario especifiar uno de: -solid, -mod, -gradient\n
2 No se pudieron crear los atomos de pixmaps, me rindo!
3 -display <string>        conexin a un display\n\
-mod <x> <y>             diseo de modula\n\
-foreground, -fg <color> color de primer plano\n\
-background, -bg <color> color de fondo\n\n\
-gradient <texture>      gradiente de textura\n\
-from <color>            color inicial del gradiente\n\
-to <color>              color final del gradiente\n\
-solid <color>           color slido\n\n\
-help                    mostrar este texto de ayuda y salir\n

$set 19 #main

1 error: '-display' requiere un argumento
4 Fuera de rango
5 Error de rutina
6 Execepcin estndar
7 Error desconocido
8 error: '-log' requiere un argumento
9 Archivo de registro
10 Guardando registro en
11 error: '-rc' requiere un argumento
12 error: '-screen' requiere un argumento
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tusar conexion a un diplay.\n\
-screen <all|int,int,int>\tejecutar solamente en pantallas especificadas.\n\
-rc <string>\t\t\tusar archivo de recursos alternativo.\n\
-version\t\t\tmostrar versin y salir.\n\
-info\t\t\t\tmostrar informacin til.\n\
-log <filename>\t\t\tregistrar salidas en archivo.\n\
-help\t\t\t\tmostrar esta ayuda y salir.\n\n
14 atencin: no se pudo establecer la variable de entorno 'DISPLAY'

$set 20 #layers

1 Sobre dock
2 Abajo
3 Escritorio
4 Dock
5 Normal
6 Arriba

==> fluxbox-1.0.0.tar.bz2: fluxbox-1.0.0/nls/es_AR/Translation.m <==
$ codeset=ISO-8859-15

$set 1 #Align

1 Abajo al centro
2 Abajo a la izquierda
3 Abajo a la derecha
4 Horizontal
5 A la izquierda
6 A la izquierda abajo
7 A la izquierda al centro
8 A la izquierda arriba
9 Relativo
10 A la derecha
11 A la derecha abajo
12 A la derecha al centro
13 A la derecha arriba
14 Arriba al centro
15 Arriba a la izquierda
16 Arriba a la derecha
17 Vertical

$set 2 #BaseDisplay

1 Abortando... volcando nucleo\n
2 Apagando\n
3 %s:       seal %d capturada\n

$set 3 #Common

1 Alfa
2 Auto ocultar
3 Compilado
4 Opciones compiladas
5 Compilador
6 Versin del compilador
7      init
8      keys
9       nls
10      menu
11     style
12 Opciones por defecto
13 desactivado
14 Error
15 Versin de Fluxbox
16 Maximizar por encima
17 Revisin de SVN
18 Visible
19 No hay una opcin de fondo especificada en este estilo.\nPor vafor consulte el manual o lea las FAQ.

$set 4 #Configmenu

1 Anti alias
2 Elevar automticamente las ventanas
3 Seleccionar para elevar
4 Seleccionar para enfocar
5 Decorar las ventanas transitivas
6 Cambiar de escritorio con la rueda del mouse
7 Enfocar ltima ventana en el cambio de escritorio
8 Modelo de enfoque
9 Enfocar ventanas nuevas
10 Maximizacin total
11 Simulacin de colores en imgenes
12 Movimiento opaco de ventanas
14 El mouse enfoca
15 Workspace Warping
16 Forzar pseudo transparencias
17 Alfa del menu
18 Transparencia
19 Alfa de ventana enfocada
20 Alfa de ventana desenfocada
21 Opciones de solapas
22 Solapas en barra de ttulo
23 Ancho de solapas externas
24 Click sobre la solapa enfoca
25 Mouse sobre la solapa enfoca

$set 5 #Ewmh

1 Fatal: Sin memoria, no se puede asignar la lista de clientes EWMH

$set 6 #FbTkError

1 Atencin! Altura > 3200, estableciendo Altura = 3200
2 Atencin! Ancho > 3200, estableciendo Ancho = 3200
3 Atencin: no se puede cargar la fuente
4 Error de asignacin.
5 Error creando el pixmap
6 No se puede crear XImage
7 Error de lectura
8 Atencin: No se puede encontrar un formato vlido para el alfa
9 Atencin: Error al crear la imagen alfa
10 Atencin: Error al crear el pixmap alfa
11 No se puede encontrar un formato para la pantalla(%d)
12 Sin memoria
13 Sin memoria mientras se asignaba buffer azul.
14 Sin memoria mientras se asignaba buffer verde.
15 Sin memoria mientras se asignaba buffer rojo.
16 Error de lectura en tem de tema
17 visual no soportada
18 Estableciendo el valor por defecto

$set 7 #Fluxbox

1 nombre de archivo rc invlido
2 Error al cargar archivo group
3 Error al cargar la base de datos
4 Reintentando con
5 Atencin! No se puede encontrar pantalla para mapear la ventana
6 No se puede crear el directorio %s
7 No se pudieron encontrar pantallas para manejar.\nAsegrese que no tiene otro gestor de ventanas ejecutndose
8 Error interpretando expresin regular
9 Error Fatal! Slo puede haber una instancia de clase de FLuxbox.
10 No se puede conectar con el servidor X.\nAsegrese de iniciar las X antes de iniciar Fluxbox
11 Atencin: el servidor X no soporta sus locales
12 Atencin: no se pueden establecer modificadores de locales

$set 8 #Gnome

1 Error Fatal: Sin memoria, no se puede asignar la lista de clientes de GNOME

$set 9 #Keys

1 Keys: Error en la lnea
2 Keys: Error al unir el rbol de teclas!
3 Keys: Tecla/modificador invlido en la lnea

$set 10 #Menu

1 Configuracin
2 Men Fluxbox por defecto
3 Salir
4 Iconos
5 Capa...
6 A la cabeza...
7 Ubicacin
8 Recargar configuracin
9 Reiniciar
10 Atencin: etiquetas desbalanceadas de [codificacin]

$set 11 #Remember

1 Decoraciones
2 Dimensiones
3 Saltar al escritorio
4 Capa
5 Recordar...
6 Posicin
7 Guardar al cerrar
8 Enrollado
9 Pegajoso
10 Tecla desconocida de aplicaciones
11 Escritorio
12 Cabeza
13 Transparencia

$set 12 #Screen

1 BScreen::BScreen: Ocurri un error al consultar al servidor X.\n     ya existe un window manager connectado al display
2 W: %4d x H: %4d
3 BScreen::BScreen: manejando pantalla %d utilizando visual 0x%lx, profundidad %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Clientes
2 Ciclar hacia abajo
3 Ciclar hacia arriba
4 Direccin de slit
5 Capa de slit
6 Slit a la cabeza
7 Ubicacin de slit
8 Slit
9 Guardar lista de slit

$set 14 #Toolbar

1 Renombrar escritorio actual
2 Modo de la barra de iconos
3 Todas las ventanas
4 Iconos
5 Ninguno
6 Escritorio
7 Iconos del escritorio
8 Capa de la barra de herramientas
9 Toolbar a la cabeza
10 Ubicacin de la barra de herramientas
11 Barra de herramientas
12 Porcentaje de ancho de la barra de herramientas
13 Reloj: 24h
14 Reloj: 12h
15 Editar el formato de reloj
16 Mostrar imgenes
17 Sin iconos
18 No mostrar los iconos del escritorio

$set 15 #Window

1 Sin nombre

$set 16 #Windowmenu

1 Cerrar
2 Iconificar
3 Capa
4 Bajar
5 Maximizar
6 Elevar
7 Enviar a ...
8 Enrollar
9 Fijar
10 Matar
11 Utilizar valores por defecto

$set 17 #Workspace

1 Escritorio %d
2 Escritorios
3 Escritorio nuevo
4 Quitar el ltimo escritorio

$set 18 #fbsetroot

1 Error: es necesario especifiar uno de: -solid, -mod, -gradient\n
2 No se pudieron crear los atomos de pixmaps, me rindo!
3 -display <string>        conectar a un display\n\
-mod <x> <y>             diseo de modula\n\
-foreground, -fg <color> color de primer plano\n\
-background, -bg <color> color de fondo\n\n\
-gradient <texture>      gradiente de textura\n\
-from <color>            color inicial del gradiente\n\
-to <color>              color final del gradiente\n\
-solid <color>           color slido\n\n\
-help                    mostrar este texto de ayuda y salir\n

$set 19 #main

1 error: '-display' requiere un argumento
2 Asignacin Invlida
3 Molde Invlido
4 Fuera de rango
5 Error de rutina
6 Execepcin estndar
7 Error desconocido
8 error: '-log' requiere un argumento
9 Archivo de registro
10 Guardando registro en
11 error: '-rc' requiere un argumento
12 error: '-screen' requiere un argumento
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
Pgina web: http://www.fluxbox.org/\n\n\
-display <string>\t\tutilizar conexion a un diplay.\n\
-screen <all|int,int,int>\tejecutar solamente en pantallas especificadas.\n\
-rc <string>\t\t\tusar archivo de recursos alternativo.\n\
-version\t\t\tmostrar versin y salir.\n\
-info\t\t\t\tmostrar informacin til.\n\
-log <filename>\t\t\tregistrar salidas en archivo.\n\
-help\t\t\t\tmostrar esta ayuda y salir.\n\n
14 atencin: no se pudo establecer la variable de entorno 'DISPLAY'

$set 20 #layers

1 Sobre dock
2 Abajo
3 Escritorio
4 Dock
5 Normal
6 Arriba
